ArtifactEvent class

3.3 — an artifact was accepted (verified + non-duplicate).

Inheritance

Constructors

ArtifactEvent(HsiArtifact artifact)
const

Properties

artifact → HsiArtifact
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited