CapabilityProvider class abstract

Provider interface for capability checking

Implementers

Constructors

CapabilityProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canAccessFeature(String moduleId, String featureId) → bool
Check if a module can access a specific feature
capability(Module module) → CapabilityLevel
Get the capability level for a specific module
getAllCapabilities() → Map<Module, CapabilityLevel>
Get all capabilities as a map
isFeatureEnabled(FeatureFlag feature) → bool
Check if a specific feature is enabled
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited