CoreRuntimeSyniServiceTransport class

Native transport backed by the registered Synheart Core runtime handle.

Implemented types

Constructors

CoreRuntimeSyniServiceTransport(CoreRuntimeBridge _runtime)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAvailable → bool
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

chat(Map<String, dynamic> request) → Future<Map<String, dynamic>>
override
closeSession(String sessionId) → Future<Map<String, dynamic>>
override
getSession(String sessionId) → Future<Map<String, dynamic>>
override
getSessionMessages(String sessionId, {int limit = 0}) → Future<Map<String, dynamic>>
override
listSessions({int limit = 0}) → Future<Map<String, dynamic>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited