HrSample class

3.1 — a scalar HR sample.

Constructors

HrSample({required double bpm, required int timestampMs, String? source})
const

Properties

bpm → double
Beats per minute.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
Producer source (e.g. healthkit); null when omitted.
final
timestampMs → int
Sample time, epoch milliseconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override