QueueFlushResult class

Constructors

QueueFlushResult({required bool success, required int uploaded, required int failed, required int requeued, String? errorMessage})
const

Properties

errorMessage → String?
final
failed → int
final
hashCode → int
The hash code for this object.
no setterinherited
requeued → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final
uploaded → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited