SleepScoreAdjust class
Constructors
- SleepScoreAdjust({required int debtPenalty, required int hrAdjustment})
-
const
-
SleepScoreAdjust.fromJson(Map<
String, Object?> json) -
factory
Properties
- debtPenalty → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hrAdjustment → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited