SleepScoreMode enum

Mode derived from history length (0→cold, 1–6→short, ≥7→stable in Kotlin-parity v2.0.0).

Inheritance
Available extensions

Values

coldStart → const SleepScoreMode
const SleepScoreMode('cold_start')
shortHistory → const SleepScoreMode
const SleepScoreMode('short_history')
stable → const SleepScoreMode
const SleepScoreMode('stable')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wire → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromWire(String s) → SleepScoreMode

Constants

values → const List<SleepScoreMode>
A constant List of the values in this enum, in order of their declaration.