SyniServiceChatResponse class
Completed non-streaming Syni service chat turn.
- Annotations
Constructors
-
SyniServiceChatResponse({required String sessionId, required String reply, SyniServiceModelInfo? model, Map<
String, dynamic> ? state, required Map<String, dynamic> raw}) -
const
-
SyniServiceChatResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- model → SyniServiceModelInfo?
-
final
-
raw
→ Map<
String, dynamic> -
final
- reply → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
-
state
→ Map<
String, dynamic> ? -
final
- usedModelFallback → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited