WearSample class

Raw wear sample from a data source

Constructors

WearSample({required DateTime timestamp, double? hr, double? hrvRmssd, double? respRate, double? motionLevel, SleepStage? sleepStage, List<double>? rrIntervals})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hr → double?
final
hrvRmssd → double?
final
motionLevel → double?
final
respRate → double?
final
rrIntervals → List<double>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sleepStage → SleepStage?
final
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited