WindowRange class

Optional filter for querying HSI windows.

Constructors

WindowRange({int? startMs, int? endMs, int? limit})
const

Properties

endMs → int?
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startMs → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited